@@ -3,6 +3,7 @@ import inspect
 
 import matplotlib.pyplot as plt
 import networkx as nx
+import setuptools
 from networkx.drawing.nx_pydot import graphviz_layout
 
 from fibonacci import fib
@@ -44,4 +45,5 @@ def draw(function):
 
 
 if __name__ == "__main__":
+    print(setuptools.find_packages())
     draw(fib)
